@@ -1,4 +1,4 @@
-# $Id: Request.pm 42205 2014-09-10 15:00:35Z wsl $
+# $Id: Request.pm 46806 2017-07-26 15:48:10Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/WS/Alias/Delete/Request.pm $
 
 use utf8;
@@ -28,7 +28,7 @@ field new_alias => sub {
 
 		if($note->[0] eq 'ok') {
 			warn $text;
-			$self->mailtje("[kiki] $who deleted $name", $text);
+			$self->mailtje("[kiki] $who deleted $name", $alias->diff);
 			$self->activate;
 		}
 	} else {
